From c7cd8787615780fe3db4ead0947cadc34abcd0e7 Mon Sep 17 00:00:00 2001
From: Deepak Khatri <lorforlinux@beagleboard.org>
Date: Fri, 31 May 2024 17:18:43 +0530
Subject: [PATCH] Add license terms modal

---
 _templates/license-terms.html          | 32 ++++++++++++++++++++++++
 boards/beaglebone/ai-64/index.rst      |  9 -------
 boards/beaglebone/ai/index.rst         |  9 -------
 boards/beaglebone/black/index.rst      |  8 ------
 boards/beaglebone/blue/index.rst       |  7 ------
 boards/beagleconnect/freedom/index.rst |  9 -------
 boards/beagleplay/index.rst            |  9 -------
 boards/beaglev/ahead/index.rst         |  9 -------
 boards/beaglev/fire/index.rst          |  9 -------
 boards/beagley/ai/index.rst            |  9 -------
 boards/pocketbeagle/index.rst          |  8 ------
 conf.py                                | 16 +++++++++---
 conf.yml                               | 34 +++++++++++++++++++++++---
 13 files changed, 75 insertions(+), 93 deletions(-)
 create mode 100644 _templates/license-terms.html

diff --git a/_templates/license-terms.html b/_templates/license-terms.html
new file mode 100644
index 00000000..175a75a5
--- /dev/null
+++ b/_templates/license-terms.html
@@ -0,0 +1,32 @@
+{% for board, path, page, git, forum in board_details %}
+    {% if path+'/' in pagename %}
+        <a role="button" data-bs-toggle="modal" data-bs-target="#licenseTerms" href="#">
+            <i class="fa-regular fa-rectangle-list"></i> License Terms
+        </a>
+
+        <div class="modal fade" id="licenseTerms" aria-labelledby="licenseTermsLabel" aria-hidden="true">
+            <div class="modal-dialog modal-lg modal-dialog-centered">
+                <div class="modal-content">
+                <div class="modal-header">
+                    <h5 class="modal-title m-0 text-dark" id="licenseTermsLabel">{{board}} - License Terms</h5>
+                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
+                </div> 
+                <div class="modal-body">
+                    <ul class="list-group list-group-flush">
+                        <li class="list-group-item">This work is licensed under a <a href="https://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a></li>
+                        <li class="list-group-item">Design materials and license can be found in the <a href="{{git}}">{{board}} git repository</a></li>
+                        <li class="list-group-item">Use of the boards or design materials constitutes an agreement to the <a href="{{docs_url}}/boards/terms-and-conditions.html">Terms & Conditions</a></li>
+                        <li class="list-group-item">Software images and purchase links available on the <a href="{{page}}">{{board}} board page</a></li>
+                        <li class="list-group-item">For export, emissions and other compliance, see <a href="{{docs_url}}/{{path}}/06-support.html">Support Information</a></li>
+                        <li class="list-group-item">All support for this design is through BeagleBoard.org community at <a href="{{forum}}">BeagleBoard.org forum.</a></li>
+                    </ul>
+                </div>
+                </div>
+            </div>
+        </div>
+
+        <script>
+            document.body.appendChild(document.getElementById('licenseTerms'));
+        </script>
+    {% endif %}
+{% endfor %}
\ No newline at end of file
diff --git a/boards/beaglebone/ai-64/index.rst b/boards/beaglebone/ai-64/index.rst
index 154fe6fd..9b128ce9 100644
--- a/boards/beaglebone/ai-64/index.rst
+++ b/boards/beaglebone/ai-64/index.rst
@@ -11,15 +11,6 @@ are all that need to be added to start building performance-optimized embedded a
 expansion possibilities are enabled through familiar BeagleBone® cape headers, with hundreds of open-source
 hardware examples and dozens of readily available embedded expansion options available off-the-shelf.
 
-.. admonition:: License Terms
-
-    * This work is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleboard/beaglebone-ai-64>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglebone-ai-64>`__
-    * For export, emissions and other compliance, see :ref:`bbai64-support`
-    * All support for this design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/bbai64>`_.
-
 .. image:: images/bbai64-45-front.jpg
    :width: 740px
    :align: center
diff --git a/boards/beaglebone/ai/index.rst b/boards/beaglebone/ai/index.rst
index 8105f2ea..9f76999b 100644
--- a/boards/beaglebone/ai/index.rst
+++ b/boards/beaglebone/ai/index.rst
@@ -10,15 +10,6 @@ digital-signal-processor (DSP) cores and embedded-vision-engine (EVE) cores supp
 optimized TIDL machine learning OpenCL API with pre-installed tools. Focused on everyday 
 automation in industrial, commercial and home applications.
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleboard/beaglebone-ai>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglebone-ai>`__
-    * For export, emissions and other compliance, see :ref:`bbai-support`
-    * All support for BeagleBone AI design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/bbai>`_.
-
 .. image:: images/BB_AI_handheld_500px.jpg
     :width: 740
     :align: center
diff --git a/boards/beaglebone/black/index.rst b/boards/beaglebone/black/index.rst
index f4b37758..253f0540 100644
--- a/boards/beaglebone/black/index.rst
+++ b/boards/beaglebone/black/index.rst
@@ -6,14 +6,6 @@ BeagleBone Black
 BeagleBone Black is a low-cost, community-supported development platform for developers and hobbyists. 
 Boot Linux in under 10 seconds and get started on development in less than 5 minutes with just a single USB cable.
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleboard/beaglebone-black>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglebone-black>`__
-    * For export, emissions and other compliance, see :ref:`beagleboneblack-support`
-
 .. image:: images/image1.jpg
    :width: 598
    :align: center
diff --git a/boards/beaglebone/blue/index.rst b/boards/beaglebone/blue/index.rst
index a57a847d..170f0347 100644
--- a/boards/beaglebone/blue/index.rst
+++ b/boards/beaglebone/blue/index.rst
@@ -15,13 +15,6 @@ robotics by `UCSD Flow Control and Coordinated Robotics Lab <http://robotics.ucs
 `WowWee <http://www.wowwee.com/mip/>`_, `National Instruments LabVIEW <http://www.ni.com/labview/>`_ 
 and of course the `BeagleBoard.org Foundation <https://beagleboard.org/about>`_.
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `OpenBeagle repository <https://openbeagle.org/beagleboard/beaglebone-blue>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglebone-blue>`__
-
 .. toctree::
    :maxdepth: 1
    
diff --git a/boards/beagleconnect/freedom/index.rst b/boards/beagleconnect/freedom/index.rst
index 7ae08d05..d9179204 100644
--- a/boards/beagleconnect/freedom/index.rst
+++ b/boards/beagleconnect/freedom/index.rst
@@ -21,15 +21,6 @@ over-the-air upgrades (OTA) capability. This MCU provides flexible support for m
     This is a work in progress, for latest documentation please 
     visit https://docs.beagleboard.org/latest/
 
-.. admonition:: License Terms
-
-   * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-   * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleconnect/freedom>`__
-   * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-   * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beagleconnect-freedom>`__
-   * For export, emissions and other compliance, see :ref:`beagleconnect-freedom-support`
-   * All support for BeagleConnect Freedom design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/bcf>`_.
-
 .. only:: html
 
    .. grid:: 1 1 2 2
diff --git a/boards/beagleplay/index.rst b/boards/beagleplay/index.rst
index b69ce617..72a4f655 100644
--- a/boards/beagleplay/index.rst
+++ b/boards/beagleplay/index.rst
@@ -10,15 +10,6 @@ BeaglePlay
 BeaglePlay is an open-source single board computer based on the Texas Instruments AM6254 quad-core Cortex-A53 Arm SoC designed to simplify the process of adding
 sensors, actuators, indicators, human interfaces, and connectivity to a reliable embedded system.
 
-.. admonition:: License Terms
-
-   * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-   * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleplay/beagleplay>`__
-   * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-   * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beagleplay>`__
-   * For export, emissions and other compliance, see :ref:`beagleplay-support`
-   * All support for BeaglePlay design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/play>`_.
-
 .. table::
    :align: center
    :widths: auto
diff --git a/boards/beaglev/ahead/index.rst b/boards/beaglev/ahead/index.rst
index 35bbf8fb..1cf55ee1 100644
--- a/boards/beaglev/ahead/index.rst
+++ b/boards/beaglev/ahead/index.rst
@@ -8,15 +8,6 @@ BeagleBone Black allowing you to stack your favourite BeagleBone cape on top to
 Featuring a powerful quad-core RISC-V processor BeagleV Ahead is designed as an affordable
 RISC-V enabled pocket-size computer for anybody who want's to dive deep into the new RISC-V ISA.
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beaglev-ahead/beaglev-ahead>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglev-ahead>`__
-    * For export, emissions and other compliance, see :ref:`beaglev-ahead-support`
-    * All support for BeagleV Ahead design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/ahead>`_.
-
 .. image:: images/BeagleV-Ahead-with-hand.*
     :align: center
     :alt: BeagleV Ahead with hand
diff --git a/boards/beaglev/fire/index.rst b/boards/beaglev/fire/index.rst
index ff4160cd..9ef918e2 100644
--- a/boards/beaglev/fire/index.rst
+++ b/boards/beaglev/fire/index.rst
@@ -9,15 +9,6 @@ of RISC-V architecture and FPGA technology. It has the same P8 & P9 cape header
 cape on top to expand it's capability. Built around the powerful and energy-efficient RISC-V instruction set architecture (ISA) along with its versatile FPGA fabric, 
 BeagleV®-Fire SBC offers unparalleled opportunities for developers, hobbyists, and researchers to explore and experiment with RISC-V technology.
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beaglev-fire/beaglev-fire>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/beaglev-fire>`__
-    * For export, emissions and other compliance, see :ref:`beaglev-fire-support`
-    * All support for BeagleV Fire design is through BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/fire>`_.
-
 .. image:: images/BeagleV-Fire-hero.*
     :align: center
     :alt: BeagleV-Fire hero image
diff --git a/boards/beagley/ai/index.rst b/boards/beagley/ai/index.rst
index 450ed953..035cdd4c 100644
--- a/boards/beagley/ai/index.rst
+++ b/boards/beagley/ai/index.rst
@@ -9,15 +9,6 @@ BeagleY-AI
 
 BeagleY-AI is an open-source single board computer based on the Texas Instruments AM67A Arm-based vision processor.
 
-.. admonition:: License Terms
-
-   * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-   * Design materials and license can be found in the `git repository <https://openbeagle.org/beagley-ai/>`__
-   * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-   * Software images and purchase links are available on the `board page <https://www.beagleboard.org/boards/beagley-ai>`__
-   * For export, emissions and other compliance, see :ref:`beagley-ai-support`
-   * All support for BeagleY-AI design is through the BeagleBoard.org community at `BeagleBoard.org forum <https://forum.beagleboard.org/tag/beagley-ai>`_.
-
 .. image:: images/beagley-ai-board.png
 
 .. only:: html
diff --git a/boards/pocketbeagle/index.rst b/boards/pocketbeagle/index.rst
index 461d3769..55fb3915 100644
--- a/boards/pocketbeagle/index.rst
+++ b/boards/pocketbeagle/index.rst
@@ -7,14 +7,6 @@ PocketBeagle is an ultra-tiny-yet-complete open-source USB-key-fob computer.
 PocketBeagle features an incredible low cost, slick design and simple usage, 
 making PocketBeagle the ideal development board for beginners and professionals alike. 
 
-.. admonition:: License Terms
-
-    * This documentation is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-sa/4.0/>`__
-    * Design materials and license can be found in the `git repository <https://git.beagleboard.org/beagleboard/pocketbeagle>`__
-    * Use of the boards or design materials constitutes an agreement to the :ref:`boards-terms-and-conditions`
-    * Software images and purchase links available on the `board page <https://www.beagleboard.org/boards/pocketbeagle-original>`__
-    * For export, emissions and other compliance, see :ref:`pocketbeagle_support_information`
-
 .. image:: images/PocketBeagle-size-compare-small.*
    :width: 598                                     
    :align: center                                   
diff --git a/conf.yml b/conf.yml
index 4923f39b..fafee261 100644
--- a/conf.yml
+++ b/conf.yml
@@ -14,55 +14,83 @@ pdf_build: all
 # Example:
 # boards:
 #     name:
+#         page: BeagleBoard.org board page link
 #         path: First level board documentation path for board 'index.rst'
 #         pdf: True/False (optional, False if this 'pdf:' option is not added)
 #         oshw: Comma seprated file names from '_static/images/oshw' folder
 
 boards:
    BeagleBone Black:
+      page: https://www.beagleboard.org/boards/beaglebone-black
+      git: https://openbeagle.org/beagleboard/beaglebone-black
+      forum: https://forum.beagleboard.org/tag/beaglebone-black
       path: boards/beaglebone/black
       pdf: True
       oshw: BeagleBone Black_US000236.svg, BeagleBone Black Wireless_US000011.svg
    BeagleBone AI-64:
+      page: https://www.beagleboard.org/boards/beaglebone-ai-64
+      git: https://openbeagle.org/beagleboard/beaglebone-ai-64
+      forum: https://forum.beagleboard.org/tag/bbai64
       path: boards/beaglebone/ai-64
       pdf: True
       oshw: BeagleBone AI-64_US002120.svg
    BeagleBone AI:
+      page: https://www.beagleboard.org/boards/beaglebone-ai
+      git: https://openbeagle.org/beagleboard/beaglebone-ai
+      forum: https://forum.beagleboard.org/tag/bbai
       path: boards/beaglebone/ai
       pdf: True
       oshw: BeagleBone AI_US000169.svg
    BeagleBone Blue:
+      page: https://www.beagleboard.org/boards/beaglebone-blue
+      git: https://openbeagle.org/beagleboard/beaglebone-blue
+      forum: https://forum.beagleboard.org/tag/beaglebone-blue
       path: boards/beaglebone/blue
       pdf: True
       oshw: BeagleBone Blue_US000064.svg
    BeagleConnect Freedom:
+      page: https://www.beagleboard.org/boards/beagleconnect-freedom
+      git: https://openbeagle.org/beagleconnect/freedom
+      forum: https://forum.beagleboard.org/tag/bcf
       path: boards/beagleconnect/freedom
       pdf: True
       oshw: BeagleConnect Freedom_US002175.svg
    BeaglePlay:
+      page: https://www.beagleboard.org/boards/beagleplay
+      git: https://openbeagle.org/beagleplay/beagleplay
+      forum: https://forum.beagleboard.org/tag/beagleplay
       path: boards/beagleplay
       pdf: True
       oshw: BeaglePlay_US002174.svg
    BeagleV-Ahead:
+      page: https://www.beagleboard.org/boards/beaglev-ahead
+      git: https://openbeagle.org/beaglev-ahead/beaglev-ahead
+      forum: https://forum.beagleboard.org/tag/ahead
       path: boards/beaglev/ahead
       pdf: True
       oshw: BeagleV-Ahead_US002535.svg
    BeagleV-Fire:
+      page: https://www.beagleboard.org/boards/beaglev-fire
+      git: https://openbeagle.org/beaglev-fire/beaglev-fire
+      forum: https://forum.beagleboard.org/tag/fire
       path: boards/beaglev/fire
       pdf: True
       oshw: BeagleV Fire_US002572.svg
    BeagleY-AI:
+      page: https://www.beagleboard.org/boards/beagley-ai
+      git: https://openbeagle.org/beagley-ai/beagley-ai
+      forum: https://forum.beagleboard.org/tag/beagley-ai
       path: boards/beagley/ai
       pdf: True
       oshw: BeagleY-AI_US002616.svg
    PocketBeagle:
+      page: https://www.beagleboard.org/boards/pocketbeagle-original
+      git: https://openbeagle.org/beagleboard/pocketbeagle
+      forum: https://forum.beagleboard.org/tag/pocketbeagle
       path: boards/pocketbeagle
       pdf: True
       oshw: PocketBeagle_US000083.svg
 
-   
-
 # Books
 
 # Projects
-
diff --git a/conf.py b/conf.py
index 049f51e2..2f746d68 100644
--- a/conf.py
+++ b/conf.py
@@ -33,6 +33,7 @@ for (dirpath, dirnames, filenames) in os.walk(rst_epilog_path):
 latex_documents = []
 pdf_paths = []
 oshw_details = []
+board_details = []
 
 with open('conf.yml', 'r') as conf_file:
     conf_data = yaml.safe_load(conf_file)
@@ -51,20 +52,26 @@ with open('conf.yml', 'r') as conf_file:
                 name = board
                 path = data['path']
                 pdf = data.get('pdf', False)
+                page = data.get('page', False)
+                git = data.get('git', False)
+                forum = data.get('forum', False)
                 
                 # PDF build details
                 if(pdf and (name in pdf_build or pdf_build_all)):
                     pdf_paths.append(path)
                     tex_name = '-'.join(path.split('/')[1:])
                     latex_documents.append((path+"/index", tex_name+".tex", "", author, "manual"))
 
                 # OSHW mark details
                 oshw_data = data.get('oshw', False)
                 if oshw_data:
                     for oshw_mark_file in data['oshw'].split(','):
                         if oshw_mark_file.endswith('.svg'):
                             board, oshw_id = oshw_mark_file.lstrip().split(".")[0].split('_')
                             oshw_details.append([board, path, oshw_id])
+                
+                # Board basic details
+                board_details.append([board, path, page, git, forum])
 
 # -- General configuration --
 
@@ -215,7 +222,7 @@ html_theme_options = {
     "footer_end": ["last-updated"],
     # "content_footer_items": ["last-updated"],
     "secondary_sidebar_items": {
-        "**": ["page-toc", "edit-this-page", "sourcelink","pdf", "feedback", "forum", "oshw"]
+        "**": ["page-toc", "edit-this-page", "sourcelink","pdf", "feedback", "forum", "license-terms", "message", "oshw"]
     },
 }
 
@@ -303,7 +310,8 @@ html_context = {
     "edit_page_provider_name": "OpenBeagle",
     "my_vcs_site": "https://openbeagle.org/docs/docs.beagleboard.io/-/edit/main/",
     "oshw_details": oshw_details,
-    "pdf_paths": pdf_paths
+    "pdf_paths": pdf_paths,
+    "board_details": board_details
 }
 
 # -- Options for LaTeX output --
@@ -51,20 +52,26 @@ with open('conf.yml', 'r') as conf_file:
                 
-                # PDF build details
+                # Board PDF build details
                 if(pdf and (name in pdf_build or pdf_build_all)):
                     pdf_paths.append(path)
@@ -51,20 +52,26 @@ with open('conf.yml', 'r') as conf_file:
                     latex_documents.append((path+"/index", tex_name+".tex", "", author, "manual"))
 
-                # OSHW mark details
+                # Board OSHW mark details
                 oshw_data = data.get('oshw', False)
                 if oshw_data:
-- 
GitLab